from __future__ import annotations
import meshsdk.trimpy
import numpy
import typing
import typing_extensions
__all__: list[str] = ['edgeBitSetFromBools', 'faceBitSetFromBools', 'fromNumpyArray', 'getNumpy3Darray', 'getNumpyBitSet', 'getNumpyCurvature', 'getNumpyFaces', 'getNumpyGaussianCurvature', 'getNumpyMeanCurvature', 'getNumpyVerts', 'meshFromFacesVerts', 'meshFromUVPoints', 'pointCloudFromPoints', 'polyline2FromPoints', 'simpleVolumeFrom3Darray', 'toNumpyArray', 'undirectedEdgeBitSetFromBools', 'vertBitSetFromBools']
def edgeBitSetFromBools(boolArray: typing_extensions.Buffer) -> meshsdk.trimpy.EdgeBitSet:
    """
    returns EdgeBitSet from numpy array with bools
    """
def faceBitSetFromBools(boolArray: typing_extensions.Buffer) -> meshsdk.trimpy.FaceBitSet:
    """
    returns FaceBitSet from numpy array with bools
    """
def fromNumpyArray(coords: typing_extensions.Buffer) -> meshsdk.trimpy.std_vector_Vector3_float:
    """
    constructs trimpy.vectorVector3f from numpy ndarray with shape (n,3)
    """
def getNumpy3Darray(simpleVolume: meshsdk.trimpy.SimpleVolume) -> numpy.ndarray[numpy.float64]:
    """
    Convert SimpleVolume to numpy 3D array
    """
def getNumpyBitSet(bitset: meshsdk.trimpy.BitSet) -> numpy.ndarray[bool]:
    """
    returns numpy array with bools for each bit of given bitset
    """
def getNumpyCurvature(mesh: meshsdk.trimpy.Mesh) -> numpy.ndarray[numpy.float64]:
    """
    retunrs numpy array with discrete mean curvature for each vertex of a mesh
    """
def getNumpyFaces(topology: meshsdk.trimpy.MeshTopology) -> numpy.ndarray[numpy.int32]:
    """
    returns numpy array shapes [num faces,3] which represents vertices of mesh valid faces 
    """
def getNumpyGaussianCurvature(mesh: meshsdk.trimpy.Mesh) -> numpy.ndarray[numpy.float64]:
    """
    retunrs numpy array with discrete Gaussian curvature for each vertex of a mesh
    """
def getNumpyMeanCurvature(mesh: meshsdk.trimpy.Mesh) -> numpy.ndarray[numpy.float64]:
    """
    retunrs numpy array with discrete mean curvature for each vertex of a mesh
    """
def getNumpyVerts(mesh: meshsdk.trimpy.Mesh) -> numpy.ndarray[numpy.float64]:
    """
    returns numpy array shapes [num verts,3] which represents coordinates of all mesh points (including invalid ones)
    """
def meshFromFacesVerts(faces: typing_extensions.Buffer, verts: typing_extensions.Buffer, settings: meshsdk.trimpy.MeshBuilder.BuildSettings = ..., duplicateNonManifoldVertices: bool = True) -> meshsdk.trimpy.Mesh:
    """
    constructs mesh from given numpy ndarrays of faces (N VertId x3, FaceId x1), verts (M vec3 x3)
    """
def meshFromUVPoints(xArray: typing_extensions.Buffer, yArray: typing_extensions.Buffer, zArray: typing_extensions.Buffer) -> meshsdk.trimpy.Mesh:
    """
    constructs mesh from three 2d numpy ndarrays with x,y,z positions of mesh
    """
def pointCloudFromPoints(points: typing_extensions.Buffer, normals: typing_extensions.Buffer = ...) -> meshsdk.trimpy.PointCloud:
    """
    creates point cloud object from numpy arrays, first arg - points, second optional arg - normals
    """
def polyline2FromPoints(points: typing_extensions.Buffer) -> meshsdk.trimpy.Polyline2:
    """
    creates polyline2 object from numpy array
    """
def simpleVolumeFrom3Darray(3DvoxelsArray: typing_extensions.Buffer) -> meshsdk.trimpy.SimpleVolumeMinMax:
    """
    Convert numpy 3D array to SimpleVolume
    """
@typing.overload
def toNumpyArray(coords: meshsdk.trimpy.VertCoords) -> numpy.ndarray[numpy.float64]:
    """
    returns numpy array shapes [num coords,3] which represents coordinates from given vector
    """
@typing.overload
def toNumpyArray(coords: meshsdk.trimpy.FaceNormals) -> numpy.ndarray[numpy.float64]:
    """
    returns numpy array shapes [num coords,3] which represents coordinates from given vector
    """
@typing.overload
def toNumpyArray(coords: meshsdk.trimpy.std_vector_Vector3_float) -> numpy.ndarray[numpy.float64]:
    """
    returns numpy array shapes [num coords,3] which represents coordinates from given vector
    """
def undirectedEdgeBitSetFromBools(boolArray: typing_extensions.Buffer) -> meshsdk.trimpy.UndirectedEdgeBitSet:
    """
    returns UndirectedEdgeBitSet from numpy array with bools
    """
def vertBitSetFromBools(boolArray: typing_extensions.Buffer) -> meshsdk.trimpy.VertBitSet:
    """
    returns VertBitSet from numpy array with bools
    """



from __future__ import annotations
import meshsdk.trimpy
from meshsdk.trimpy import func_bool_from_float
from meshsdk.trimpy import func_tl_expected_void_std_string_from_VoxelsVolumeMinMax_Vector_float_Id_VoxelTag_int
from meshsdk.trimpy import func_tl_expected_void_std_string_from_std_vector_float_Vector3_int_int
from meshsdk.trimpy import int_output
from meshsdk.trimpy import std_vector_MeshIntersectionResult
from meshsdk.trimpy import std_vector_MeshProjectionResult
from meshsdk.trimpy import std_vector_MeshTriPoint
from meshsdk.trimpy import std_vector_PointsProjectionResult
from meshsdk.trimpy import std_vector_SkyPatch
from meshsdk.trimpy import std_vector_Vector3_float
from meshsdk.trimpy import std_vector_Vector3_float as std_vector_Vector3f
from meshsdk.trimpy import std_vector_float
import typing
__all__: list[str] = ['ComputeToolDistance', 'FastWindingNumber', 'PointsProjector', 'PointsToMeshProjector', 'computeDistanceMap', 'computeDistanceMapHeapBytes', 'computeSkyViewFactor', 'distanceMapFromContours', 'distanceMapFromContoursHeapBytes', 'findProjectionOnPoints', 'findProjectionOnPointsHeapBytes', 'findSkyRays', 'func_bool_from_float', 'func_tl_expected_void_std_string_from_VoxelsVolumeMinMax_Vector_float_Id_VoxelTag_int', 'func_tl_expected_void_std_string_from_std_vector_float_Vector3_int_int', 'getCudaAvailableMemory', 'getCudaSafeMemoryLimit', 'int_output', 'isCudaAvailable', 'loadMRCudaDll', 'maxBufferSize', 'maxBufferSizeAlignedByBlock', 'negatePicture', 'pointsToDistanceVolume', 'pointsToDistanceVolumeByParts', 'std_vector_MeshIntersectionResult', 'std_vector_MeshProjectionResult', 'std_vector_MeshTriPoint', 'std_vector_PointsProjectionResult', 'std_vector_SkyPatch', 'std_vector_Vector3_float', 'std_vector_Vector3f', 'std_vector_float']
class ComputeToolDistance(meshsdk.trimpy.IComputeToolDistance):
    """
    Generated from:  MR::Cuda::ComputeToolDistance
    
    CUDA implementation of tool distance computation
    """
    def __init__(self) -> None:
        ...
    def computeToolDistance(self, output: meshsdk.trimpy.std_vector_float, dims: meshsdk.trimpy.Vector3i, voxelSize: float, origin: meshsdk.trimpy.Vector3f, padding: float) -> None:
        ...
    @typing.overload
    def prepare(self, dims: meshsdk.trimpy.Vector3i, toolpath: meshsdk.trimpy.Polyline3, toolSpec: meshsdk.trimpy.EndMillTool) -> meshsdk.trimpy.Vector3i:
        ...
    @typing.overload
    def prepare(self, dims: meshsdk.trimpy.Vector3i, toolpath: meshsdk.trimpy.Polyline3, toolProfile: meshsdk.trimpy.Polyline2) -> meshsdk.trimpy.Vector3i:
        ...
class FastWindingNumber(meshsdk.trimpy.IFastWindingNumber, meshsdk.trimpy.IFastWindingNumberByParts):
    """
    Generated from:  MR::Cuda::FastWindingNumber
    
    the class for fast approximate computation of winding number for a mesh (using its AABB tree)
    """
    @staticmethod
    @typing.overload
    def __init__(*args, **kwargs) -> None:
        ...
    @typing.overload
    def __init__(self, mesh: meshsdk.trimpy.Mesh) -> None:
        """
        constructs this from AABB tree of given mesh;
        """
    @typing.overload
    def __init__(self, arg0: FastWindingNumber) -> None:
        """
        Implicit copy constructor.
        """
    def calcFromGrid(self, res: meshsdk.trimpy.std_vector_float, dims: meshsdk.trimpy.Vector3i, gridToMeshXf: meshsdk.trimpy.AffineXf3f, beta: float, cb: meshsdk.trimpy.func_bool_from_float) -> None:
        ...
    def calcFromGridByParts(self, resFunc: meshsdk.trimpy.func_tl_expected_void_std_string_from_std_vector_float_Vector3_int_int, dims: meshsdk.trimpy.Vector3i, gridToMeshXf: meshsdk.trimpy.AffineXf3f, beta: float, layerOverlap: int, cb: meshsdk.trimpy.func_bool_from_float) -> None:
        """
        see methods' descriptions in IFastWindingNumberByParts
        """
    def calcFromGridWithDistances(self, res: meshsdk.trimpy.std_vector_float, dims: meshsdk.trimpy.Vector3i, gridToMeshXf: meshsdk.trimpy.AffineXf3f, options: meshsdk.trimpy.DistanceToMeshOptions, cb: meshsdk.trimpy.func_bool_from_float) -> None:
        ...
    def calcFromGridWithDistancesByParts(self, resFunc: meshsdk.trimpy.func_tl_expected_void_std_string_from_std_vector_float_Vector3_int_int, dims: meshsdk.trimpy.Vector3i, gridToMeshXf: meshsdk.trimpy.AffineXf3f, options: meshsdk.trimpy.DistanceToMeshOptions, layerOverlap: int, cb: meshsdk.trimpy.func_bool_from_float) -> None:
        ...
    def calcFromVector(self, res: meshsdk.trimpy.std_vector_float, points: meshsdk.trimpy.std_vector_Vector3_float, beta: float, skipFace: meshsdk.trimpy.FaceId, cb: meshsdk.trimpy.func_bool_from_float) -> None:
        """
        see methods' descriptions in IFastWindingNumber
        """
    def calcSelfIntersections(self, res: meshsdk.trimpy.FaceBitSet, beta: float, cb: meshsdk.trimpy.func_bool_from_float) -> None:
        ...
class PointsProjector(meshsdk.trimpy.IPointsProjector):
    """
    Generated from:  MR::Cuda::PointsProjector
    
    CUDA-backed implementation of IPointsProjector
    """
    @staticmethod
    @typing.overload
    def __init__(*args, **kwargs) -> None:
        ...
    @staticmethod
    @typing.overload
    def operator(*args, **kwargs) -> PointsProjector:
        ...
    @staticmethod
    @typing.overload
    def operator(*args, **kwargs) -> PointsProjector:
        ...
    @typing.overload
    def __init__(self) -> None:
        ...
    @typing.overload
    def __init__(self, arg0: PointsProjector) -> None:
        """
        Implicit copy constructor.
        """
    def findProjections(self, results: meshsdk.trimpy.std_vector_PointsProjectionResult, points: meshsdk.trimpy.std_vector_Vector3_float, settings: meshsdk.trimpy.FindProjectionOnPointsSettings) -> None:
        """
        computes the closest points on point cloud to given points
        """
    def projectionsHeapBytes(self, numProjections: int) -> int:
        """
        Returns amount of additional memory needed to compute projections
        """
    def setPointCloud(self, pointCloud: meshsdk.trimpy.PointCloud) -> None:
        """
        sets the reference point cloud
        """
class PointsToMeshProjector(meshsdk.trimpy.IPointsToMeshProjector):
    """
    Generated from:  MR::Cuda::PointsToMeshProjector
    
    Computes the closest point on mesh to each of given points on GPU. It caches data that necessary for computing
    """
    @staticmethod
    @typing.overload
    def __init__(*args, **kwargs) -> None:
        ...
    @staticmethod
    @typing.overload
    def operator(*args, **kwargs) -> PointsToMeshProjector:
        ...
    @staticmethod
    @typing.overload
    def operator(*args, **kwargs) -> PointsToMeshProjector:
        ...
    @typing.overload
    def __init__(self) -> None:
        ...
    @typing.overload
    def __init__(self, arg0: PointsToMeshProjector) -> None:
        """
        Implicit copy constructor.
        """
    def findProjections(self, res: meshsdk.trimpy.std_vector_MeshProjectionResult, points: meshsdk.trimpy.std_vector_Vector3_float, objXf: meshsdk.trimpy.AffineXf3f, refObjXf: meshsdk.trimpy.AffineXf3f, upDistLimitSq: float, loDistLimitSq: float) -> None:
        """
        <summary>
        Computes the closest point on mesh to each of given points
        </summary>
        <param name="res">vector pf projections</param>
        <param name="points">vector of points to project</param>
        <param name="objXf">transform applied to points</param>
        <param name="refObjXf">transform applied to referencing mesh</param>
        <param name="upDistLimitSq">maximal squared distance from point to mesh</param>
        <param name="loDistLimitSq">minimal squared distance from point to mesh</param>
        """
    def projectionsHeapBytes(self, numProjections: int) -> int:
        """
        Returns amount of additional memory needed to compute projections
        """
    def updateMeshData(self, mesh: meshsdk.trimpy.Mesh) -> None:
        """
        update all data related to the referencing mesh
        """
def computeDistanceMap(mesh: meshsdk.trimpy.Mesh, params: meshsdk.trimpy.MeshToDistanceMapParams, cb: meshsdk.trimpy.func_bool_from_float = '{}', outSamples: meshsdk.trimpy.std_vector_MeshTriPoint = None) -> meshsdk.trimpy.DistanceMap:
    """
    computes distance (height) map for given projection parameters
    using float-precision for finding ray-mesh intersections, which is faster but less reliable
    """
def computeDistanceMapHeapBytes(mesh: meshsdk.trimpy.Mesh, params: meshsdk.trimpy.MeshToDistanceMapParams, needOutSamples: bool = False) -> int:
    """
    Computes memory consumption of computeDistanceMap function
    """
def computeSkyViewFactor(terrain: meshsdk.trimpy.Mesh, samples: meshsdk.trimpy.VertCoords, validSamples: meshsdk.trimpy.VertBitSet, skyPatches: meshsdk.trimpy.std_vector_SkyPatch, outSkyRays: meshsdk.trimpy.BitSet = None, outIntersections: meshsdk.trimpy.std_vector_MeshIntersectionResult = None) -> meshsdk.trimpy.VertScalars:
    """
    computes relative radiation in each valid sample point by emitting rays from that point in the sky:
    the radiation is 1.0f if all rays reach the sky not hitting the terrain;
    the radiation is 0.0f if all rays do not reach the sky because they are intercepted by the terrain;
    \\param outSkyRays - optional output bitset where for every valid sample #i its rays are stored at indices [i*numPatches; (i+1)*numPatches),
                        0s for occluded rays (hitting the terrain) and 1s for the ones which don't hit anything and reach the sky
    \\param outIntersections - optional output vector of MeshIntersectionResult for every valid sample point
    """
def distanceMapFromContours(polyline: meshsdk.trimpy.Polyline2, params: meshsdk.trimpy.ContourToDistanceMapParams) -> meshsdk.trimpy.DistanceMap:
    """
    Computes distance of 2d contours according to ContourToDistanceMapParams (works correctly only when withSign==false)
    """
def distanceMapFromContoursHeapBytes(polyline: meshsdk.trimpy.Polyline2, params: meshsdk.trimpy.ContourToDistanceMapParams) -> int:
    """
    Computes memory consumption of distanceMapFromContours function
    """
def findProjectionOnPoints(pointCloud: meshsdk.trimpy.PointCloud, points: meshsdk.trimpy.std_vector_Vector3_float, settings: meshsdk.trimpy.FindProjectionOnPointsSettings = '{}') -> meshsdk.trimpy.std_vector_PointsProjectionResult:
    """
    computes the closest points on point cloud to given points
    """
def findProjectionOnPointsHeapBytes(pointCloud: meshsdk.trimpy.PointCloud, pointsCount: int) -> int:
    """
    returns the minimal amount of free GPU memory required for \\ref MR::Cuda::findProjectionOnPoints
    """
def findSkyRays(terrain: meshsdk.trimpy.Mesh, samples: meshsdk.trimpy.VertCoords, validSamples: meshsdk.trimpy.VertBitSet, skyPatches: meshsdk.trimpy.std_vector_SkyPatch, outIntersections: meshsdk.trimpy.std_vector_MeshIntersectionResult = None) -> meshsdk.trimpy.BitSet:
    """
    In each valid sample point tests the rays from that point in the sky;
    \\return bitset where for every valid sample #i its rays are stored at indices [i*numPatches; (i+1)*numPatches),
            0s for occluded rays (hitting the terrain) and 1s for the ones which don't hit anything and reach the sky
    \\param outIntersections - optional output vector of MeshIntersectionResult for every valid sample point
    """
def getCudaAvailableMemory() -> int:
    """
    Returns available GPU memory in bytes
    """
def getCudaSafeMemoryLimit() -> int:
    """
    Returns maximum safe amount of free GPU memory that will be used for dynamic-sized buffers
    """
def isCudaAvailable(driverVersion: meshsdk.trimpy.int_output = None, runtimeVersion: meshsdk.trimpy.int_output = None, computeMajor: meshsdk.trimpy.int_output = None, computeMinor: meshsdk.trimpy.int_output = None) -> bool:
    """
    Returns true if Cuda is present on this GPU
    optional out maximum driver supported version
    optional out current runtime version
    optional out compute capability major version
    optional out compute capability minor version
    """
def loadMRCudaDll() -> None:
    """
    call this function to load MRCuda shared library
    """
def maxBufferSize(availableBytes: int, elementCount: int, elementBytes: int) -> int:
    """
    Returns maximum buffer size in elements that can be allocated with given memory limit
    """
@typing.overload
def maxBufferSizeAlignedByBlock(availableBytes: int, blockDims: meshsdk.trimpy.Vector2i, elementBytes: int) -> int:
    """
    Returns maximum buffer size in elements that can be allocated with given memory limit
    The size is aligned to the block dimensions
    """
@typing.overload
def maxBufferSizeAlignedByBlock(availableBytes: int, blockDims: meshsdk.trimpy.Vector3i, elementBytes: int) -> int:
    ...
def negatePicture(image: meshsdk.trimpy.Image) -> None:
    """
    This function inverts Color value (255 - value in each channel except alpha) 
    """
def pointsToDistanceVolume(cloud: meshsdk.trimpy.PointCloud, params: meshsdk.trimpy.PointsToDistanceVolumeParams) -> meshsdk.trimpy.SimpleVolumeMinMax:
    """
    makes SimpleVolume filled with signed distances to points with normals
    """
def pointsToDistanceVolumeByParts(cloud: meshsdk.trimpy.PointCloud, params: meshsdk.trimpy.PointsToDistanceVolumeParams, addPart: meshsdk.trimpy.func_tl_expected_void_std_string_from_VoxelsVolumeMinMax_Vector_float_Id_VoxelTag_int, layerOverlap: int) -> None:
    """
    makes SimpleVolume filled with signed distances to points with normals
    populate the volume by parts to the given callback
    """



from __future__ import annotations
import meshsdk.trimpy
import typing
__all__: list[str] = ['KeyMod', 'MouseButton', 'UiEntry', 'UiEntryType', 'UiValueInt', 'UiValueReal', 'UiValueString', 'UiValueUint', 'Viewer', 'ViewerLaunchParams', 'ViewerLaunchParamsMode', 'ViewerSetup', 'Viewport', 'ViewportFitDataParams', 'ViewportFitMode', 'addDistanceMapToScene', 'addLinesToScene', 'addMeshToScene', 'addPointCloudToScene', 'addVoxelsToScene', 'clearScene', 'getSelectedDistanceMaps', 'getSelectedMeshEdges', 'getSelectedMeshFaces', 'getSelectedMeshes', 'getSelectedObjects', 'getSelectedPointCloudPoints', 'getSelectedPointClouds', 'getSelectedPolylines', 'getSelectedVoxels', 'launch', 'modifySelectedMesh', 'runFromGUIThread', 'selectByName', 'selectByType', 'setSelectedMeshEdges', 'setSelectedMeshFaces', 'setSelectedPointCloudPoints', 'uiListEntries', 'uiPressButton', 'uiReadValueInt', 'uiReadValueReal', 'uiReadValueString', 'uiReadValueUint', 'uiWriteValue', 'uiWriteValueInt', 'uiWriteValueReal', 'uiWriteValueString', 'uiWriteValueUint', 'unselectAll']
class KeyMod:
    """
    Members:
    
      Empty
    
      Ctrl
    
      Super
    
      Shift
    
      Alt
    """
    Alt: typing.ClassVar[KeyMod]  # value = <KeyMod.Alt: 4>
    Ctrl: typing.ClassVar[KeyMod]  # value = <KeyMod.Ctrl: 2>
    Empty: typing.ClassVar[KeyMod]  # value = <KeyMod.Empty: 0>
    Shift: typing.ClassVar[KeyMod]  # value = <KeyMod.Shift: 1>
    Super: typing.ClassVar[KeyMod]  # value = <KeyMod.Super: 8>
    __members__: typing.ClassVar[dict[str, KeyMod]]  # value = {'Empty': <KeyMod.Empty: 0>, 'Ctrl': <KeyMod.Ctrl: 2>, 'Super': <KeyMod.Super: 8>, 'Shift': <KeyMod.Shift: 1>, 'Alt': <KeyMod.Alt: 4>}
    def __and__(self, arg0: KeyMod) -> KeyMod:
        ...
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __invert__(self) -> KeyMod:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __or__(self, arg0: KeyMod) -> KeyMod:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class MouseButton:
    """
    Members:
    
      Left
    
      Right
    
      Middle
    """
    Left: typing.ClassVar[MouseButton]  # value = <MouseButton.Left: 0>
    Middle: typing.ClassVar[MouseButton]  # value = <MouseButton.Middle: 2>
    Right: typing.ClassVar[MouseButton]  # value = <MouseButton.Right: 1>
    __members__: typing.ClassVar[dict[str, MouseButton]]  # value = {'Left': <MouseButton.Left: 0>, 'Right': <MouseButton.Right: 1>, 'Middle': <MouseButton.Middle: 2>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class UiEntry:
    def __repr__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def type(self) -> UiEntryType:
        ...
class UiEntryType:
    """
    UI entry type enum.
    
    Members:
    
      button
    
      group
    
      valueInt
    
      valueUint
    
      valueReal
    
      valueString
    
      other
    """
    __members__: typing.ClassVar[dict[str, UiEntryType]]  # value = {'button': <UiEntryType.button: 0>, 'group': <UiEntryType.group: 1>, 'valueInt': <UiEntryType.valueInt: 2>, 'valueUint': <UiEntryType.valueUint: 3>, 'valueReal': <UiEntryType.valueReal: 4>, 'valueString': <UiEntryType.valueString: 5>, 'other': <UiEntryType.other: 6>}
    button: typing.ClassVar[UiEntryType]  # value = <UiEntryType.button: 0>
    group: typing.ClassVar[UiEntryType]  # value = <UiEntryType.group: 1>
    other: typing.ClassVar[UiEntryType]  # value = <UiEntryType.other: 6>
    valueInt: typing.ClassVar[UiEntryType]  # value = <UiEntryType.valueInt: 2>
    valueReal: typing.ClassVar[UiEntryType]  # value = <UiEntryType.valueReal: 4>
    valueString: typing.ClassVar[UiEntryType]  # value = <UiEntryType.valueString: 5>
    valueUint: typing.ClassVar[UiEntryType]  # value = <UiEntryType.valueUint: 3>
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class UiValueInt:
    @property
    def max(self) -> int:
        ...
    @property
    def min(self) -> int:
        ...
    @property
    def value(self) -> int:
        ...
class UiValueReal:
    @property
    def max(self) -> float:
        ...
    @property
    def min(self) -> float:
        ...
    @property
    def value(self) -> float:
        ...
class UiValueString:
    @property
    def allowed(self) -> list[str] | None:
        ...
    @property
    def value(self) -> str:
        ...
class UiValueUint:
    @property
    def max(self) -> int:
        ...
    @property
    def min(self) -> int:
        ...
    @property
    def value(self) -> int:
        ...
class Viewer:
    """
    GLFW-based mesh viewer
    """
    def __init__(self) -> None:
        ...
    def captureScreenShot(self, path: str) -> None:
        """
        Captures part of window (redraw 3d scene over UI (without redrawing UI))
        """
    def captureUIScreenShot(self, path: str) -> None:
        """
        Captures full window screenshot with UI
        """
    def getMousePos(self) -> meshsdk.trimpy.Vector2f:
        """
        Get the current mouse position.
        """
    def incrementForceRedrawFrames(self, num: int = 1, swapOnLastOnly: bool = False) -> None:
        """
        Increment number of forced frames to redraw in event loop
        if `swapOnLastOnly` only last forced frame will be present on screen and all previous will not
        """
    def mouseDown(self, button: MouseButton, modifier: KeyMod = ...) -> None:
        """
        Simulate mouse down event.
        """
    def mouseMove(self, x: int, y: int) -> None:
        """
        Simulate mouse move event.
        NOTE: Some plugins need at least TWO `mouseMove()`s in a row (possibly with the same position). If you're having issues, try sending two events.
        """
    def mouseUp(self, button: MouseButton, modifier: KeyMod = ...) -> None:
        """
        Simulate mouse up event.
        """
    def preciseFitDataViewport(self, vpList: meshsdk.trimpy.ViewportMask = ..., params: ViewportFitDataParams = ...) -> None:
        """
        Calls fitData and change FOV to match the screen size then
        params - params fit data
        """
    def showSceneTree(self, show: bool) -> None:
        """
        Shows or hide scene tree
        """
    def shutdown(self) -> None:
        """
        sets stop event loop flag (this flag is glfwShouldWindowClose equivalent)
        """
    def skipFrames(self, frames: int) -> None:
        ...
    def viewport(self, viewportId: meshsdk.trimpy.ViewportId = ...) -> Viewport:
        """
        Return the current viewport, or the viewport corresponding to a given unique identifier
        	viewportId - unique identifier corresponding to the desired viewport (current viewport if 0)
        """
    def viewportToScreen(self, arg0: meshsdk.trimpy.Vector3f, arg1: meshsdk.trimpy.ViewportId) -> meshsdk.trimpy.Vector3f:
        """
        Convert viewport coordinates to to screen coordinates
        """
class ViewerLaunchParams:
    """
    This struct contains rules for viewer launch
    """
    height: int
    width: int
    windowMode: ViewerLaunchParamsMode
    def __init__(self) -> None:
        ...
    @property
    def animationMaxFps(self) -> int:
        """
        max fps if animating
        """
    @animationMaxFps.setter
    def animationMaxFps(self, arg0: int) -> None:
        ...
    @property
    def fullscreen(self) -> bool:
        """
        if true starts fullscreen
        """
    @fullscreen.setter
    def fullscreen(self, arg0: bool) -> None:
        ...
    @property
    def isAnimating(self) -> bool:
        """
        if true - calls render without system events
        """
    @isAnimating.setter
    def isAnimating(self, arg0: bool) -> None:
        ...
    @property
    def name(self) -> str:
        """
        Window name
        """
    @name.setter
    def name(self, arg0: str) -> None:
        ...
class ViewerLaunchParamsMode:
    """
    Members:
    
      Hide : Don't show window
    
      HideInit : Show window after init
    
      Show : Show window immediately
    
      TryHidden : Launches in "Hide" mode if OpenGL is present and "NoWindow" if it is not
    
      NoWindow : Don't initialize GL window (don't call GL functions)(force `isAnimating`)
    """
    Hide: typing.ClassVar[ViewerLaunchParamsMode]  # value = <ViewerLaunchParamsMode.Hide: 2>
    HideInit: typing.ClassVar[ViewerLaunchParamsMode]  # value = <ViewerLaunchParamsMode.HideInit: 1>
    NoWindow: typing.ClassVar[ViewerLaunchParamsMode]  # value = <ViewerLaunchParamsMode.NoWindow: 4>
    Show: typing.ClassVar[ViewerLaunchParamsMode]  # value = <ViewerLaunchParamsMode.Show: 0>
    TryHidden: typing.ClassVar[ViewerLaunchParamsMode]  # value = <ViewerLaunchParamsMode.TryHidden: 3>
    __members__: typing.ClassVar[dict[str, ViewerLaunchParamsMode]]  # value = {'Hide': <ViewerLaunchParamsMode.Hide: 2>, 'HideInit': <ViewerLaunchParamsMode.HideInit: 1>, 'Show': <ViewerLaunchParamsMode.Show: 0>, 'TryHidden': <ViewerLaunchParamsMode.TryHidden: 3>, 'NoWindow': <ViewerLaunchParamsMode.NoWindow: 4>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
class ViewerSetup:
    def __init__(self) -> None:
        ...
class Viewport:
    """
    Viewport is a rectangular area, in which the objects of interest are going to be rendered.
    An application can have a number of viewports each with its own ID.
    """
    def cameraLookAlong(self, dir: meshsdk.trimpy.Vector3f, up: meshsdk.trimpy.Vector3f) -> None:
        """
        Set camera look direction and up direction (they should be perpendicular)
        this function changes camera position and do not change camera spot (0,0,0) by default
        to change camera position use setCameraTranslation after this function
        """
    def cameraRotateAround(self, axis: meshsdk.trimpy.Line3f, angle: float) -> None:
        """
        Rotates camera around axis +direction applied to axis point
        note: this can make camera clip objects (as far as distance to scene center is not fixed)
        """
    def projectToViewportSpace(self, arg0: meshsdk.trimpy.Vector3f) -> meshsdk.trimpy.Vector3f:
        """
        Project world space point to viewport coordinates (in pixels), (0,0) will be at the top-left corner of the viewport.
        """
    @property
    def id(self) -> meshsdk.trimpy.ViewportId:
        ...
class ViewportFitDataParams:
    def __init__(self) -> None:
        ...
    @property
    def factor(self) -> float:
        """
        part of the screen for scene location
        """
    @factor.setter
    def factor(self, arg0: float) -> None:
        ...
    @property
    def mode(self) -> ViewportFitMode:
        """
        fit mode
        """
    @mode.setter
    def mode(self, arg0: ViewportFitMode) -> None:
        ...
    @property
    def snapView(self) -> bool:
        """
        snapView - to snap camera angle to closest canonical quaternion
        """
    @snapView.setter
    def snapView(self, arg0: bool) -> None:
        ...
class ViewportFitMode:
    """
    Fit mode ( types of objects for which the fit is applied )
    
    Members:
    
      Visible : fit all visible objects
    
      SelectedObjects : fit only selected objects
    
      SelectedPrimitives : fit only selected primitives
    """
    SelectedObjects: typing.ClassVar[ViewportFitMode]  # value = <ViewportFitMode.SelectedObjects: 2>
    SelectedPrimitives: typing.ClassVar[ViewportFitMode]  # value = <ViewportFitMode.SelectedPrimitives: 1>
    Visible: typing.ClassVar[ViewportFitMode]  # value = <ViewportFitMode.Visible: 0>
    __members__: typing.ClassVar[dict[str, ViewportFitMode]]  # value = {'Visible': <ViewportFitMode.Visible: 0>, 'SelectedObjects': <ViewportFitMode.SelectedObjects: 2>, 'SelectedPrimitives': <ViewportFitMode.SelectedPrimitives: 1>}
    def __eq__(self, other: typing.Any) -> bool:
        ...
    def __getstate__(self) -> int:
        ...
    def __hash__(self) -> int:
        ...
    def __index__(self) -> int:
        ...
    def __init__(self, value: int) -> None:
        ...
    def __int__(self) -> int:
        ...
    def __ne__(self, other: typing.Any) -> bool:
        ...
    def __repr__(self) -> str:
        ...
    def __setstate__(self, state: int) -> None:
        ...
    def __str__(self) -> str:
        ...
    @property
    def name(self) -> str:
        ...
    @property
    def value(self) -> int:
        ...
def addDistanceMapToScene(distancemap: meshsdk.trimpy.DistanceMap, name: str, dmap_to_local_xf: meshsdk.trimpy.AffineXf3f) -> None:
    """
    Add given distance map to scene tree.
    """
def addLinesToScene(lines: meshsdk.trimpy.Polyline3, name: str) -> None:
    """
    Add given lines to scene tree.
    """
def addMeshToScene(mesh: meshsdk.trimpy.Mesh, name: str) -> None:
    """
    Add given mesh to scene tree.
    """
def addPointCloudToScene(points: meshsdk.trimpy.PointCloud, name: str) -> None:
    """
    Add given point cloud to scene tree.
    """
def addVoxelsToScene(voxels: meshsdk.trimpy.VdbVolume, name: str) -> None:
    """
    Add given voxels to scene tree.
    """
def clearScene() -> None:
    """
    remove all objects from scene tree
    """
def getSelectedDistanceMaps() -> meshsdk.trimpy.std_vector_DistanceMap:
    """
    Get copies of all selected voxel grids in the scene.
    """
def getSelectedMeshEdges() -> meshsdk.trimpy.std_vector_TypedBitSet_Id_UndirectedEdgeTag:
    """
    Get selected edge bitsets of the selected mesh objects.
    """
def getSelectedMeshFaces() -> meshsdk.trimpy.std_vector_TypedBitSet_Id_FaceTag:
    """
    Get selected face bitsets of the selected mesh objects.
    """
def getSelectedMeshes() -> meshsdk.trimpy.std_vector_Mesh:
    """
    Get copies of all selected meshes in the scene.
    """
def getSelectedObjects() -> meshsdk.trimpy.std_vector_std_shared_ptr_Object:
    ...
def getSelectedPointCloudPoints() -> meshsdk.trimpy.std_vector_TypedBitSet_Id_VertTag:
    """
    Get selected point bitsets of the selected point cloud objects.
    """
def getSelectedPointClouds() -> meshsdk.trimpy.std_vector_PointCloud:
    """
    Get copies of all selected point clouds in the scene.
    """
def getSelectedPolylines() -> meshsdk.trimpy.std_vector_Polyline_Vector3_float:
    """
    Get copies of all selected polylines in the scene.
    """
def getSelectedVoxels() -> meshsdk.trimpy.std_vector_VoxelsVolumeMinMax_FloatGrid:
    """
    Get copies of all selected voxel grids in the scene.
    """
def launch(params: ViewerLaunchParams = ..., setup: ViewerSetup = ...) -> None:
    """
    starts default viewer with given params and setup
    """
def modifySelectedMesh(mesh: meshsdk.trimpy.Mesh) -> None:
    """
    Assign a new mesh to the selected mesh object. Exactly one object must be selected.
    """
def runFromGUIThread(lambda: typing.Callable) -> None:
    """
    Executes given function from GUI thread, and returns after it is done
    """
def selectByName(objectName: str) -> None:
    """
    select objects in scene tree with given name, unselect others
    """
def selectByType(typeName: str) -> None:
    """
    string typeName: {"Meshes", "Points", "Voxels"}
    objects in scene tree with given type, unselect others
    """
def setSelectedMeshEdges(arg0: meshsdk.trimpy.std_vector_TypedBitSet_Id_UndirectedEdgeTag) -> None:
    """
    Set selected edge bitsets of the selected mesh objects.
    """
def setSelectedMeshFaces(arg0: meshsdk.trimpy.std_vector_TypedBitSet_Id_FaceTag) -> None:
    """
    Set selected face bitsets of the selected mesh objects.
    """
def setSelectedPointCloudPoints(arg0: meshsdk.trimpy.std_vector_TypedBitSet_Id_VertTag) -> None:
    """
    Set selected point bitsets of the selected point cloud objects.
    """
def uiListEntries(arg0: list[str]) -> list[UiEntry]:
    """
    List existing UI entries at the specified path.
    Pass an empty list to see top-level groups.
    Add group name to the end of the vector to see its contents.
    When you find the button you need, pass it to `uiPressButton()`.
    """
def uiPressButton(arg0: list[str]) -> None:
    """
    Simulate a button click. Use `uiListEntries()` to find button names.
    """
def uiReadValueInt(arg0: list[str]) -> UiValueInt:
    """
    Read a value from a drag/slider widget. This function is for signed integers.
    """
def uiReadValueReal(arg0: list[str]) -> UiValueReal:
    """
    Read a value from a drag/slider widget. This function is for real numbers.
    """
def uiReadValueString(arg0: list[str]) -> UiValueString:
    """
    Read a value from a drag/slider widget. This function is for strings.
    """
def uiReadValueUint(arg0: list[str]) -> UiValueUint:
    """
    Read a value from a drag/slider widget. This function is for unsigned integers.
    """
@typing.overload
def uiWriteValue(arg0: list[str], arg1: int) -> None:
    """
    Write a value to a drag/slider widget. This overload is for signed integers.
    """
@typing.overload
def uiWriteValue(arg0: list[str], arg1: int) -> None:
    """
    Write a value to a drag/slider widget. This overload is for unsigned integers.
    """
@typing.overload
def uiWriteValue(arg0: list[str], arg1: float) -> None:
    """
    Write a value to a drag/slider widget. This overload is for real numbers.
    """
@typing.overload
def uiWriteValue(arg0: list[str], arg1: str) -> None:
    """
    Write a value to a drag/slider widget. This overload is for strings.
    """
def uiWriteValueInt(arg0: list[str], arg1: int) -> None:
    """
    Write a value to a drag/slider widget. This overload is for signed integers.
    """
def uiWriteValueReal(arg0: list[str], arg1: float) -> None:
    """
    Write a value to a drag/slider widget. This overload is for real numbers.
    """
def uiWriteValueString(arg0: list[str], arg1: str) -> None:
    """
    Write a value to a drag/slider widget. This overload is for strings.
    """
def uiWriteValueUint(arg0: list[str], arg1: int) -> None:
    """
    Write a value to a drag/slider widget. This overload is for unsigned integers.
    """
def unselectAll() -> None:
    """
    unselect all objects in scene tree
    """
